@@ -2,6 +2,7 @@ package receivepack
 
 import (
 	"context"
+	"os"
 
 	"google.golang.org/grpc"
 
@@ -23,15 +24,15 @@ func (c *Command) performGitalyCall(response *accessverifier.Response) error {
 
 	request := &pb.SSHReceivePackRequest{
 		Repository:       &response.Gitaly.Repo,
-		GlId:             response.UserId,
+		GlId:             response.Who,
 		GlRepository:     response.Repo,
 		GlUsername:       response.Username,
-		GitProtocol:      response.GitProtocol,
+		GitProtocol:      os.Getenv(commandargs.GitProtocolEnv),
 		GitConfigOptions: response.GitConfigOptions,
 	}
 
 	return gc.RunGitalyCommand(func(ctx context.Context, conn *grpc.ClientConn) (int32, error) {
-		ctx, cancel := context.WithCancel(ctx)
+		ctx, cancel := gc.PrepareContext(ctx, request.Repository, response, request.GitProtocol)
 		defer cancel()
 
 		rw := c.ReadWriter
