@@ -2,18 +2,15 @@ package uploadpack
 
 import (
 	"bytes"
-	"strings"
+	"context"
 	"testing"
 
-	"github.com/sirupsen/logrus"
-
-	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
+	"gitlab.com/gitlab-org/gitlab-shell/client/testserver"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/command/commandargs"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/command/readwriter"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/config"
-	"gitlab.com/gitlab-org/gitlab-shell/internal/gitlabnet/testserver"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/testhelper"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/testhelper/requesthandlers"
 )
@@ -40,21 +37,24 @@ func TestUploadPack(t *testing.T) {
 
 	hook := testhelper.SetupLogger()
 
-	err := cmd.Execute()
+	err := cmd.Execute(context.Background())
 	require.NoError(t, err)
 
 	require.Equal(t, "UploadPack: "+repo, output.String())
-	require.Equal(t, logrus.InfoLevel, hook.LastEntry().Level)
-	require.True(t, strings.Contains(hook.LastEntry().Message, "executing git command"))
-	require.True(t, strings.Contains(hook.LastEntry().Message, "command=git-upload-pack"))
+	entries := hook.AllEntries()
+	require.Equal(t, 2, len(entries))
+	require.Contains(t, entries[1].Message, "executing git command")
+	require.Contains(t, entries[1].Message, "command=git-upload-pack")
+	require.Contains(t, entries[1].Message, "gl_key_type=key")
+	require.Contains(t, entries[1].Message, "gl_key_id=123")
 
 	for k, v := range map[string]string{
 		"gitaly-feature-cache_invalidator":        "true",
 		"gitaly-feature-inforef_uploadpack_cache": "false",
 	} {
 		actual := testServer.ReceivedMD[k]
-		assert.Len(t, actual, 1)
-		assert.Equal(t, v, actual[0])
+		require.Len(t, actual, 1)
+		require.Equal(t, v, actual[0])
 	}
-	assert.Empty(t, testServer.ReceivedMD["some-other-ff"])
+	require.Empty(t, testServer.ReceivedMD["some-other-ff"])
 }
